@@ -75,12 +75,7 @@ namespace {
 				for(const auto& attribute : cfg.attribute_range())
 				{
 					std::string val = attribute.second.str();
-					if(std::search(val.begin(),
-						val.end(),
-						filter.begin(),
-						filter.end(),
-						utils::chars_equal_insensitive)
-						!= val.end())
+					if(translation::ci_search(val, filter))
 					{
 						found = true;
 						break;
@@ -555,7 +550,7 @@ void addon_manager::toggle_details(button& btn, stacked_widget& stk)
 
 void addon_manager::fetch_addons_list()
 {
-	bool success = client_.request_addons_list(cfg_);
+	bool success = client_.request_addons_list(cfg_, preferences::addon_icons());
 	if(!success) {
 		gui2::show_error_message(_("An error occurred while downloading the add-ons list from the server."));
 		get_window()->close();
@@ -1046,8 +1041,10 @@ static std::string format_addon_time(std::time_t time)
 
 		const std::string format = preferences::use_twelve_hour_clock_format()
 			// TRANSLATORS: Month + day of month + year + 12-hour time, eg 'November 02 2021, 1:59 PM'. Format for your locale.
+			// Format reference: https://www.boost.org/doc/libs/1_85_0/doc/html/date_time/date_time_io.html#date_time.format_flags
 			? _("%B %d %Y, %I:%M %p")
 			// TRANSLATORS: Month + day of month + year + 24-hour time, eg 'November 02 2021, 13:59'. Format for your locale.
+			// Format reference: https://www.boost.org/doc/libs/1_85_0/doc/html/date_time/date_time_io.html#date_time.format_flags
 			: _("%B %d %Y, %H:%M");
 
 		ss << translation::strftime(format, std::localtime(&time));
